==> XOOPS2_mod_analog_0.2_beta_kizumo.zip: analog/admin/execution.php <==
<?php

/**
* $Id: execution.php,v 1.2 2005/03/04 06:48:40 kizumo Exp $
* Module: analog
* Author: kizumo
* Licence: GNU
*/

$op = '';
if (isset($_POST)) {
	foreach ($_POST as $k => $v) {
		${$k} = $v;
	}
}

if (isset($_GET['op'])) {
	$op = $_GET['op'];
}

$form_action = $_SERVER['PHP_SELF'];
$configuration_handler =& xoops_getmodulehandler('configuration');
switch ($op) {
case "execution":
    if (isset($confid)) {
        $cfgarray['HOSTNAME'] = $xoopsConfig['sitename'];
        $cfgarray['LOGFILE'] = $xoopsModuleConfig['LOGFILE'];
        $cfgarray['IMAGEDIR'] = $xoopsModuleConfig['IMAGEDIR'];
        $cfgarray['LANGUAGE'] = $xoopsModuleConfig['LANGUAGE'];
        $cfgarray['OUTPUT'] = $xoopsModuleConfig['OUTPUT'];
        $cfgarray['FROM'] = $_POST['FROM'];
        $cfgarray['TO'] = $_POST['TO'];
        $preference = $configuration_handler->get($confid);
        foreach ($preference->getVar("configuration") as $k => $v) {
            if (preg_match("/^[A-Z]/", $k) && $v != '') {
                $cfgarray[$k] = $v;
            }
        }
        $cfg = '';
        $logfile = array();
        foreach ($cfgarray as $k => $v) {
            if ($k == "FROM") {
                $cfg .= $k . " " . $_POST['FROM'];
                $cfg .= "\n";
            } elseif($k == "TO") {
                $cfg .= $k . " " . $_POST['TO'];
                $cfg .= "\n";
            } else {
                $cfg .= $k . " " . $v;
                $cfg .= "\n";
            }
        }
        $tmp = '';
        foreach ($_POST['LOGFILE'] as $k => $v) {
            if ($_POST['LOGFORMAT'][$k] != '') {
                $tmp .= 'LOGFORMAT ' . $_POST['LOGFORMAT'][$k];
                $tmp .= "\n";
            }
            if ($_POST['LOGTIMEOFFSET'][$k] != '') {
                $tmp .= 'LOGTIMEOFFSET ' . $_POST['LOGTIMEOFFSET'][$k];
                $tmp .= "\n";
            }
            if ($_POST['LOGFILE'][$k] != '') {
                $tmp .= 'LOGFILE ' . $_POST['LOGFILE'][$k];
                $tmp .= "\n";
            }
        }
        $cfg = $tmp . $cfg;
//print nl2br($cfg);
/* */
        $fp = popen("echo -e '$cfg' | ".$xoopsModuleConfig['analog']." +g-", "r");
        while (!feof($fp)) {
            $buffer = fgets($fp, 4096);
            echo $buffer;
        }
        pclose($fp);
/* */
    } else {
        redirect_header('index.php', 4, _AM_AG_DBNOUPDATED);
        exit();
    }
    break;

case "select":
default:
    xoops_cp_header();
    ag_adminMenu(1, _AM_AG_EXECUTION);
    echo "<div style='clear: left'>";
    echo "<div id='toptable'>";

    $configuration = $configuration_handler->getObjects();
    $form = new XoopsThemeForm(_AM_AG_SELECTCONF, "select", $form_action);
    $conf_select = new XoopsFormSelect(_AM_AG_SELECTCONF, "confid", $confid);
    $conf_select->addOption('', '-------');
    foreach ($configuration as $obj) {
        $conf_select->addOption($obj->getVar('confid'), $obj->getVar('name'));
    }
    $conf_select->setExtra("onChange=\"submit();\"");
    $form->addElement($conf_select);
    $form->addElement(new XoopsFormHidden("op", "select"));
    $form->display();
    echo "</div>";

    if (isset($confid) && $confid > 0) {
        echo "<div id='toptable'>";
        $form = new XoopsThemeForm(_AM_AG_SELECTCONF, "analog", $form_action);
        $preference = $configuration_handler->get($confid);
        $configuration = $preference->getVar('configuration');
        $fromto_tray = new XoopsFormElementTray(_AM_AG_FROMTO, "");
        $from_text = 
                new XoopsFormText(_AM_AG_FROM, "FROM", 10, 6, $configuration['FROM']);
        $to_text = 
                new XoopsFormText(_AM_AG_TO, "TO", 10, 6, $configuration['TO']);
        $fromto_tray->addElement($from_text);
        $fromto_tray->addElement($to_text);
        $form->addElement($fromto_tray);
        $log_tray = new XoopsFormElementTray(_AM_AG_LOGFILE, "<br>");
        $log_tray->setDescription(_AM_AG_LOGFILEDSC);
        foreach ($configuration['LOGFILE'] as $k => $v) {
            $log_tray_child[$k] = new XoopsFormElementTray("", "<br>");
            $log_tray_child[$k]->addElement(new XoopsFormLabel(sprintf("<span style='font-weight: bold;'>%s[%u]</span>", _AM_AG_LOGFILE, $k + 1)));
            $log_tray_child[$k]->addElement(new XoopsFormText(_AM_AG_LOGFORMAT, "LOGFORMAT[]", 40, 40, $configuration['LOGFORMAT'][$k]));
            $log_tray_child[$k]->addElement(new XoopsFormText(_AM_AG_LOGTIMEOFFSET, "LOGTIMEOFFSET[]", 20, 20, $configuration['LOGTIMEOFFSET'][$k]));
            $log_tray_child[$k]->addElement(new XoopsFormText(_AM_AG_LOGFILE, "LOGFILE[]", 60, 60, $configuration['LOGFILE'][$k]));
            $log_tray->addElement($log_tray_child[$k]);
        }
        $form->addElement($log_tray);
        $form->addElement(new XoopsFormHidden("op", "execution"));
        $form->addElement(new XoopsFormHidden("confid", $confid));
        $submit = new XoopsFormButton("", "exec", _SUBMIT, "submit");
        $submit->setExtra("onClick=\"form.target='_blank';\"");
        $form->addElement($submit);
        $form->display();
        echo "</div>";
    }

    echo "</div>";
    xoops_cp_footer();
}

?>

==> XOOPS2_mod_analog_0.3_beta_kizumo.zip: analog/admin/execution.php <==
<?php

/**
* $Id: execution.php,v 1.3 2005/04/01 05:20:49 kizumo Exp $
* Module: analog
* Author: kizumo
* Licence: GNU
*/

$op = '';
if (isset($_POST)) {
	foreach ($_POST as $k => $v) {
		${$k} = $v;
	}
}

if (isset($_GET['op'])) {
	$op = $_GET['op'];
}

$form_action = $_SERVER['PHP_SELF'];
$configuration_handler =& xoops_getmodulehandler('configuration');
switch ($op) {
case "execution":
    if (isset($confid)) {
        $cfgarray['HOSTNAME'] = $xoopsConfig['sitename'];
        $cfgarray['LOGFILE'] = $xoopsModuleConfig['LOGFILE'];
        $cfgarray['IMAGEDIR'] = $xoopsModuleConfig['IMAGEDIR'];
        $cfgarray['LANGUAGE'] = $xoopsModuleConfig['LANGUAGE'];
        $cfgarray['OUTPUT'] = $xoopsModuleConfig['OUTPUT'];
        $cfgarray['FROM'] = $_POST['FROM'];
        $cfgarray['TO'] = $_POST['TO'];
        $preference = $configuration_handler->get($confid);
        foreach ($preference->getVar("configuration") as $k => $v) {
            if (preg_match("/^[A-Z]/", $k) && $v != '') {
                $cfgarray[$k] = $v;
            }
        }
        $cfg = '';
        $logfile = array();
        foreach ($cfgarray as $k => $v) {
            if ($k == "FROM") {
                $cfg .= $k . " " . $_POST['FROM'];
                $cfg .= "\n";
            } elseif($k == "TO") {
                $cfg .= $k . " " . $_POST['TO'];
                $cfg .= "\n";
            } else {
                $cfg .= $k . " " . $v;
                $cfg .= "\n";
            }
        }
        $tmp = '';
        foreach ($_POST['LOGFILE'] as $k => $v) {
            if ($_POST['LOGFORMAT'][$k] != '') {
                $tmp .= 'LOGFORMAT ' . $_POST['LOGFORMAT'][$k];
                $tmp .= "\n";
            }
            if ($_POST['LOGTIMEOFFSET'][$k] != '') {
                $tmp .= 'LOGTIMEOFFSET ' . $_POST['LOGTIMEOFFSET'][$k];
                $tmp .= "\n";
            }
            if ($_POST['LOGFILE'][$k] != '') {
                $tmp .= 'LOGFILE ' . $_POST['LOGFILE'][$k];
                $tmp .= "\n";
            }
        }
        $cfg = $tmp . $cfg;
//print nl2br($cfg);
/* */
        $fp = popen("echo -e '$cfg' | ".$xoopsModuleConfig['analog']." +g-", "r");
        $toencoding = "ISO-2022-JP";
        while (!feof($fp)) {
            $buffer = fgets($fp, 4096);
            if (preg_match ("/<meta http-equiv=\"Content-Type\" content=\"text\/html; charset=(.*)\"/i", $buffer, $matches)){
                $toencoding = $matches[1];
                $toencoding = strtoupper($toencoding);
            }
            $str = rawurldecode($buffer);
            $fromencoding = mb_detect_encoding($str);
            echo mb_convert_encoding($str, $toencoding, $fromencoding);
        }
        pclose($fp);
/* */
    } else {
        redirect_header('index.php', 4, _AM_AG_DBNOUPDATED);
        exit();
    }
    break;

case "select":
default:
    xoops_cp_header();
    ag_adminMenu(1, _AM_AG_EXECUTION);
    echo "<div style='clear: left'>";
    echo "<div id='toptable'>";

    $configuration = $configuration_handler->getObjects();
    $form = new XoopsThemeForm(_AM_AG_SELECTCONF, "select", $form_action);
    $conf_select = new XoopsFormSelect(_AM_AG_SELECTCONF, "confid", $confid);
    $conf_select->addOption('', '-------');
    foreach ($configuration as $obj) {
        $conf_select->addOption($obj->getVar('confid'), $obj->getVar('name'));
    }
    $conf_select->setExtra("onChange=\"submit();\"");
    $form->addElement($conf_select);
    $form->addElement(new XoopsFormHidden("op", "select"));
    $form->display();
    echo "</div>";

    if (isset($confid) && $confid > 0) {
        echo "<div id='toptable'>";
        $form = new XoopsThemeForm(_AM_AG_SELECTCONF, "analog", $form_action);
        $preference = $configuration_handler->get($confid);
        $configuration = $preference->getVar('configuration');
        $fromto_tray = new XoopsFormElementTray(_AM_AG_FROMTO, "");
        $from_text = 
                new XoopsFormText(_AM_AG_FROM, "FROM", 10, 6, $configuration['FROM']);
        $to_text = 
                new XoopsFormText(_AM_AG_TO, "TO", 10, 6, $configuration['TO']);
        $fromto_tray->addElement($from_text);
        $fromto_tray->addElement($to_text);
        $form->addElement($fromto_tray);
        $log_tray = new XoopsFormElementTray(_AM_AG_LOGFILE, "<br>");
        $log_tray->setDescription(_AM_AG_LOGFILEDSC);
        foreach ($configuration['LOGFILE'] as $k => $v) {
            $log_tray_child[$k] = new XoopsFormElementTray("", "<br>");
            $log_tray_child[$k]->addElement(new XoopsFormLabel(sprintf("<span style='font-weight: bold;'>%s[%u]</span>", _AM_AG_LOGFILE, $k + 1)));
            $log_tray_child[$k]->addElement(new XoopsFormText(_AM_AG_LOGFORMAT, "LOGFORMAT[]", 40, 40, $configuration['LOGFORMAT'][$k]));
            $log_tray_child[$k]->addElement(new XoopsFormText(_AM_AG_LOGTIMEOFFSET, "LOGTIMEOFFSET[]", 20, 20, $configuration['LOGTIMEOFFSET'][$k]));
            $log_tray_child[$k]->addElement(new XoopsFormText(_AM_AG_LOGFILE, "LOGFILE[]", 60, 60, $configuration['LOGFILE'][$k]));
            $log_tray->addElement($log_tray_child[$k]);
        }
        $form->addElement($log_tray);
        $form->addElement(new XoopsFormHidden("op", "execution"));
        $form->addElement(new XoopsFormHidden("confid", $confid));
        $submit = new XoopsFormButton("", "exec", _SUBMIT, "submit");
        $submit->setExtra("onClick=\"form.target='_blank';\"");
        $form->addElement($submit);
        $form->display();
        echo "</div>";
    }

    echo "</div>";
    xoops_cp_footer();
}

?>
